pub const fn error_code_specs() -> &'static [ErrorCodeSpec; 10]Expand description
Returns stable reference metadata for all known error codes.
pub const fn error_code_specs() -> &'static [ErrorCodeSpec; 10]Returns stable reference metadata for all known error codes.